Learn R Programming

traineR (version 2.2.11)

categorical.predictive.power: categorical.predictive.power

Description

Function that graphs the distribution of individuals and shows their category according to a categorical variable.

Usage

categorical.predictive.power(
  data,
  predict.variable,
  variable.to.compare,
  ylab = "",
  xlab = "",
  main = paste("Variable Distribution", variable.to.compare, "according to",
    predict.variable),
  col = NA
)

Value

A ggplot object.

Arguments

data

A data frame.

predict.variable

Character type. The name of the variable to predict. This name must be part of the columns of the data frame.

variable.to.compare

Character type. The name of the categorical variable to compare. This name must be part of the columns of the data frame.

ylab

A character string that describes the y-axis on the graph.

xlab

A character string that describes the x-axis on the graph.

main

Character type. The main title of the chart.

col

A vector that specifies the colors of the categories of the variable to predict.

See Also

Examples

Run this code

cars <- datasets::mtcars
cars$cyl <- as.factor(cars$cyl)
cars$vs <- as.factor(cars$vs)
categorical.predictive.power(cars,"vs","cyl")

Run the code above in your browser using DataLab