Description
Returns a matrix of contrasts for the train.kknn.
Usage
contr.dummy(n, contrasts = TRUE)
Value
A matrix with n rows and n-1 columns for contr.ordinal, a matrix with n rows and n columns for contr.dummy and a vector of length n for contr.metric.
Arguments
- n
A vector containing levels of a factor, or the number of levels.
- contrasts
A logical value indicating whether contrasts should be computed.