Return prediction for a ada model.
# S3 method for ada.prmdt
predict(object, newdata, type = "class", n.iter = NULL, ...)a vector or matrix of predictions for ada model.
a ada model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
number of iterations to consider for the prediction. By default this is iter from the ada call (n.iter< iter).
additional arguments affecting the predictions produced.