Return prediction for a naiveBayes model.
# S3 method for bayes.prmdt
predict(object, newdata, type = "class", threshold = 0.001, eps = 0, ...)a vector or matrix of predictions for bayes model.
a naiveBayes model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
Value replacing cells with 0 probabilities.
double for specifying an epsilon-range to apply laplace smoothing (to replace zero or close-zero probabilities by theshold).
additional arguments affecting the predictions produced.