Return prediction for a glm model.
# S3 method for glm.prmdt
predict(
object,
newdata,
type = "class",
se.fit = FALSE,
dispersion = NULL,
terms = NULL,
na.action = na.pass,
...
)a vector or matrix of predictions for glm model.
a glm model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
logical switch indicating if standard errors are required.
the dispersion of the GLM fit to be assumed in computing the standard errors. If omitted, that returned by summary applied to the object is used.
with type = "terms" by default all terms are returned. A character vector specifies which terms are to be returned.
function determining what should be done with missing values in newdata. The default is to predict NA.
additional arguments affecting the predictions produced.