Return prediction for a glmnet model.
# S3 method for glmnet.prmdt
predict(object, newdata, type = "class", s = NULL, ...)a glmnet model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
a cv.glmnet object (optional).
additional arguments affecting the predictions produced.