Return prediction for a train.kknn model.
# S3 method for knn.prmdt
predict(object, newdata, type = "class", ...)a vector or matrix of predictions for knn model.
a train.kknn model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
additional arguments affecting the predictions produced.