Return prediction for a lda model.
# S3 method for lda.prmdt
predict(object, newdata, type = "class", ...)a vector or matrix of predictions for lda model.
a lda model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
additional arguments affecting the predictions produced.