Learn R Programming

traineR (version 2.2.11)

predict.neuralnet.prmdt: predict.neuralnet.prmdt

Description

Return prediction for a neuralnet model.

Usage

# S3 method for neuralnet.prmdt
predict(object, newdata, type = "class", ...)

Value

a vector or matrix of predictions for neuralnet.

Arguments

object

a neuralnet model object for which prediction is desired.

newdata

an optional data frame in which to look for variables with which to predict.

type

type of prediction 'prob' or 'class' (default).

...

additional arguments affecting the predictions produced.