Return prediction for a qda model.
# S3 method for qda.prmdt
predict(object, newdata, type = "class", ...)a vector or matrix of predictions for qda model.
a qda model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
additional arguments affecting the predictions produced.