Return prediction for a gbm model.
# S3 method for gbm.prmdt
predict(
object,
newdata,
type = "class",
n.trees = NULL,
single.tree = FALSE,
...
)a vector or matrix of predictions gbm model.
a gbm model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
Number of trees used in the prediction. n.trees may be a vector in which case predictions are returned for each iteration specified
If single.tree=TRUE then predict.gbm returns only the predictions from tree(s) n.trees.
additional arguments affecting the predictions produced.