Return prediction for a neuralnet model.
# S3 method for neuralnet.prmdt
predict(object, newdata, type = "class", ...)a vector or matrix of predictions for neuralnet.
a neuralnet model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
additional arguments affecting the predictions produced.