Return prediction for a rpart model.
# S3 method for rpart.prmdt
predict(object, newdata, type = "class", na.action = na.pass, ...)a vector or matrix of predictions for rpart model.
a rpart model object for which prediction is desired.
an optional data frame in which to look for variables with which to predict.
type of prediction 'prob' or 'class' (default).
a function to determine what should be done with missing values in newdata. The default is to pass them down the tree using surrogates in the way selected when the model was built. Other possibilities are na.omit and na.fail.
additional arguments affecting the predictions produced.